@@ -7,21 +7,27 @@ chBodyCellProperties = function( x, i, j, value ){
 			, .jarray( as.integer( i-1 ) )
 			, .jarray( as.integer( j-1 ) )
 			, jcellProp  )
-	
+
 	x
 }
 
 chBodyBackgroundColor = function( x, i, j, value ){
-	
+
 	if( !all( is.color( value ) ) ) {
 		stop("value contains elements that are not valid colors")
 	}
-	
-	jflexcell = .jcall( x$jobj, "V", "setBackgroundColors"
-			, .jarray( as.integer( i-1 ) )
-			, .jarray( as.integer( j-1 ) )
-			, .jarray( as.character( value ) )  )
-	
+
+  color_compounds <- get_color_compounds(value)
+
+	jflexcell = .jcall( x$jobj, "V", "setBackgroundColors",
+      .jarray( as.integer( i-1 ) ),
+			.jarray( as.integer( j-1 ) ),
+			.jarray( color_compounds$r ),
+			.jarray( color_compounds$g ),
+			.jarray( color_compounds$b ),
+			.jarray( color_compounds$a )
+			)
+
 	x
 }
 
@@ -29,13 +35,13 @@ chBodyParProperties = function( x, i, j, value ){
 	if( !inherits( value , "parProperties" ) ){
 		stop("value is not a parProperties object")
 	}
-	
+
 	jparProp = .jParProperties( value )
 	jflexcell = .jcall( x$jobj, "V", "setParProperties"
 			, .jarray( as.integer( i-1 ) )
 			, .jarray( as.integer( j-1 ) )
 			, jparProp  )
-	
+
 	x
 }
 
@@ -43,13 +49,13 @@ chBodyTextProperties = function( x, i, j, value ){
 	if( !inherits( value , "textProperties" ) ){
 		stop("value is not a textProperties object")
 	}
-	
+
 	jtextProp = .jTextProperties( value )
 	jflexcell = .jcall( x$jobj, "V", "setTextProperties"
 			, .jarray( as.integer( i-1 ) )
 			, .jarray( as.integer( j-1 ) )
 			, jtextProp  )
-	
+
 	x
 }
 chBodyBorderProperties = function( x, i, j, side, value ){
@@ -57,23 +63,23 @@ chBodyBorderProperties = function( x, i, j, side, value ){
 	if( !inherits( value , "borderProperties" ) ){
 		stop("value is not a borderProperties object")
 	}
-	
+
 	jborderProp = .jborderProperties( value )
 	.jcall( x$jobj, "V", "setBodyBorderProperties"
 			, .jarray( as.integer( i-1 ) )
 			, .jarray( as.integer( j-1 ) )
 			, jborderProp, side )
-	
+
 	x
 }
 
 chHeaderTextProperties = function( x, i, j, value ){
-	
+
 	if( !inherits( value , "textProperties" ) ){
 		stop("value is not a textProperties object")
 	}
 	metarows = .jcall( x$jobj, "Lorg/lysis/reporters/tables/MetaRows;", "getHeader" )
-	
+
 	jtextProp = .jTextProperties( value )
 	jflexcell = .jcall( metarows, "V", "set"
 			, .jarray( as.integer( i-1 ) )
@@ -83,12 +89,12 @@ chHeaderTextProperties = function( x, i, j, value ){
 }
 
 chHeaderCellProperties = function( x, i, j, value ){
-	
+
 	if( !inherits( value , "cellProperties" ) ){
 		stop("value is not a cellProperties object")
 	}
 	metarows = .jcall( x$jobj, "Lorg/lysis/reporters/tables/MetaRows;", "getHeader" )
-	
+
 	jcellProp = .jCellProperties( value )
 	jflexcell = .jcall( metarows, "V", "set"
 			, .jarray( as.integer( i-1 ) )
@@ -97,27 +103,34 @@ chHeaderCellProperties = function( x, i, j, value ){
 	x
 }
 chHeaderBackgroundColor = function( x, i, j, value ){
-	
+
 	if( !all( is.color( value ) ) ) {
 		stop("value contains elements that are not valid colors")
 	}
-	
+
 	metarows = .jcall( x$jobj, "Lorg/lysis/reporters/tables/MetaRows;", "getHeader" )
-	
-	jflexcell = .jcall( metarows, "V", "setBackgroundColors"
-			, .jarray( as.integer( i-1 ) )
-			, .jarray( as.integer( j-1 ) )
-			, .jarray( as.character( value ) )  )
+
+	color_compounds <- get_color_compounds(value)
+
+	.jcall( metarows, "V", "setBackgroundColors",
+	  .jarray(as.integer(i - 1)),
+	  .jarray(as.integer(j - 1)),
+	  .jarray(color_compounds$r),
+	  .jarray(color_compounds$g),
+	  .jarray(color_compounds$b),
+	  .jarray(color_compounds$a)
+	)
+
 	x
 }
 
 chHeaderParProperties = function( x, i, j, value ){
-	
+
 	if( !inherits( value , "parProperties" ) ){
 		stop("value is not a parProperties object")
 	}
 	metarows = .jcall( x$jobj, "Lorg/lysis/reporters/tables/MetaRows;", "getHeader" )
-	
+
 	jparProp = .jParProperties( value )
 	jflexcell = .jcall( metarows, "V", "set"
 			, .jarray( as.integer( i-1 ) )
@@ -131,23 +144,23 @@ chHeaderBorderProperties = function( x, i, j, side, value ){
 		stop("value is not a borderProperties object")
 	}
 	metarows = .jcall( x$jobj, "Lorg/lysis/reporters/tables/MetaRows;", "getHeader" )
-	
+
 	jborderProp = .jborderProperties( value )
 	.jcall( metarows, "V", "set"
 			, .jarray( as.integer( i-1 ) )
 			, .jarray( as.integer( j-1 ) )
 			, jborderProp, side )
-	
+
 	x
 }
 
 chFooterTextProperties = function( x, i, j, value ){
-	
+
 	if( !inherits( value , "textProperties" ) ){
 		stop("value is not a textProperties object")
 	}
 	metarows = .jcall( x$jobj, "Lorg/lysis/reporters/tables/MetaRows;", "getFooter" )
-	
+
 	jtextProp = .jTextProperties( value )
 	jflexcell = .jcall( metarows, "V", "set"
 			, .jarray( as.integer( i-1 ) )
@@ -157,41 +170,48 @@ chFooterTextProperties = function( x, i, j, value ){
 }
 
 chFooterCellProperties = function( x, i, j, value ){
-	
+
 	if( !inherits( value , "cellProperties" ) ){
 		stop("value is not a cellProperties object")
 	}
 	metarows = .jcall( x$jobj, "Lorg/lysis/reporters/tables/MetaRows;", "getFooter" )
-	
+
 	jcellProp = .jCellProperties( value )
-	jflexcell = .jcall( metarows, "V", "set"
+	.jcall( metarows, "V", "set"
 			, .jarray( as.integer( i-1 ) )
 			, .jarray( as.integer( j-1 ) )
 			, jcellProp  )
 	x
 }
 chFooterBackgroundColor = function( x, i, j, value ){
-	
+
 	if( !all( is.color( value ) ) ) {
 		stop("value contains elements that are not valid colors")
 	}
-	
+
 	metarows = .jcall( x$jobj, "Lorg/lysis/reporters/tables/MetaRows;", "getFooter" )
-	
-	jflexcell = .jcall( metarows, "V", "setBackgroundColors"
-			, .jarray( as.integer( i-1 ) )
-			, .jarray( as.integer( j-1 ) )
-			, .jarray( as.character( value ) )  )
+
+	color_compounds <- get_color_compounds(value)
+
+	.jcall( metarows, "V", "setBackgroundColors",
+	        .jarray(as.integer(i - 1)),
+	        .jarray(as.integer(j - 1)),
+	        .jarray(color_compounds$r),
+	        .jarray(color_compounds$g),
+	        .jarray(color_compounds$b),
+	        .jarray(color_compounds$a)
+	)
+
 	x
 }
 
 chFooterParProperties = function( x, i, j, value ){
-	
+
 	if( !inherits( value , "parProperties" ) ){
 		stop("value is not a parProperties object")
 	}
 	metarows = .jcall( x$jobj, "Lorg/lysis/reporters/tables/MetaRows;", "getFooter" )
-	
+
 	jparProp = .jParProperties( value )
 	jflexcell = .jcall( metarows, "V", "set"
 			, .jarray( as.integer( i-1 ) )
@@ -202,9 +222,9 @@ chFooterParProperties = function( x, i, j, value ){
 chFooterBorderProperties = function( x, i, j, side, value ){
 	if( !inherits( value , "borderProperties" ) ){
 		stop("value is not a borderProperties object")
-	}	
+	}
 	metarows = .jcall( x$jobj, "Lorg/lysis/reporters/tables/MetaRows;", "getFooter" )
-	
+
 	jborderProp = .jborderProperties( value )
 	.jcall( metarows, "V", "set"
 			, .jarray( as.integer( i-1 ) )
