@@ -10,8 +10,10 @@
 #' @seealso \code{\link{pptx}}, \code{\link{docx}}
 
 is.color = function(x) {
-	sapply(x, function( x ) {
+	out = sapply(x, function( x ) {
 				tryCatch( is.matrix( col2rgb( x ) ), error = function( e ) F )
 			})
+	if(any( is.na( names(out) ) ) ) out[is.na( names(out) )] = FALSE
+	out
 }
 
