@@ -16,7 +16,6 @@ import org.docx4j.dml.CTTextParagraphProperties;
 import org.docx4j.dml.CTTextSpacing;
 import org.docx4j.dml.CTTextSpacingPoint;
 import org.docx4j.dml.STTextAlignType;
-import org.docx4j.wml.CTShd;
 import org.docx4j.wml.Jc;
 import org.docx4j.wml.JcEnumeration;
 import org.docx4j.wml.PPr;
@@ -47,7 +46,7 @@ public class ParProperties {
 	private BorderProperties borderLeft;
 	private BorderProperties borderTop;
 	private BorderProperties borderRight;
-	private String shading_color;
+	private ColorProperties shading_color;
 
 	private long ordered_num_id = -1;
 	private long unordered_num_id = -1;
@@ -114,7 +113,7 @@ public class ParProperties {
 	public int getPaddingright() {
 		return paddingright;
 	}
-	public void setShadingColor(String shadingColor){
+	public void setShadingColor(ColorProperties shadingColor){
 		shading_color = shadingColor;
 	}
 	public void setPaddingLeft(int padding ){
@@ -134,7 +133,7 @@ public class ParProperties {
 		marginbottom = margin;
 	}
 
-	public String getShadingColor() {
+	public ColorProperties getShadingColor() {
 		return shading_color;
 	}
 
@@ -174,9 +173,9 @@ public class ParProperties {
         parProperties.setSpacing(space);
         
 		if( shading_color!=null){
-			CTShd shading = new CTShd();
-			shading.setFill(shading_color);
-			parProperties.setShd(shading);
+//			CTShd shading = new CTShd();
+//			shading.setFill(shading_color);
+			parProperties.setShd(shading_color.getCT_Shd());
 		}
 		
         PBdr parBorder = new PBdr();
@@ -302,7 +301,7 @@ public class ParProperties {
 		parProperties.put("padding-left", paddingleft+"pt");	
 		
 		if( shading_color!=null){
-			parProperties.put("background-color", shading_color);
+			parProperties.put("background-color", shading_color.getrgba());
 		}
 		
 		if( marginleft > 0 ){
@@ -319,22 +318,22 @@ public class ParProperties {
 		}
 		
 		if( borderBottom.hasBorder() ){
-			parProperties.put("border-bottom-color", borderBottom.getBorderColor() );	
+			parProperties.put("border-bottom-color", borderBottom.getBorderColor().getrgba() );	
 			parProperties.put("border-bottom-style", borderBottom.getBorderStyle() );	
 			parProperties.put("border-bottom-width", borderBottom.getBorderWidth() + "px" );
 		}
 		if( borderTop.hasBorder() ){
-			parProperties.put("border-top-color", borderTop.getBorderColor() );	
+			parProperties.put("border-top-color", borderTop.getBorderColor().getrgba() );	
 			parProperties.put("border-top-style", borderTop.getBorderStyle() );	
 			parProperties.put("border-top-width", borderTop.getBorderWidth() + "px" );	
 		}
 		if( borderRight.hasBorder() ){
-			parProperties.put("border-right-color", borderRight.getBorderColor() );	
+			parProperties.put("border-right-color", borderRight.getBorderColor().getrgba() );	
 			parProperties.put("border-right-style", borderRight.getBorderStyle() );	
 			parProperties.put("border-right-width", borderRight.getBorderWidth() + "px" );
 		}
 		if( borderLeft.hasBorder() ){
-			parProperties.put("border-left-color", borderLeft.getBorderColor() );	
+			parProperties.put("border-left-color", borderLeft.getBorderColor().getrgba() );	
 			parProperties.put("border-left-style", borderLeft.getBorderStyle() );	
 			parProperties.put("border-left-width", borderLeft.getBorderWidth() + "px" );	
 		}
